aboutsummaryrefslogtreecommitdiff
path: root/git_ref.go
diff options
context:
space:
mode:
Diffstat (limited to 'git_ref.go')
-rw-r--r--git_ref.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/git_ref.go b/git_ref.go
index 65b90bf..ab8e35d 100644
--- a/git_ref.go
+++ b/git_ref.go
@@ -8,9 +8,9 @@ import (
"github.com/go-git/go-git/v5/plumbing"
)
// get_ref_hash_from_type_and_name returns the hash of a reference given its
// type and name as supplied in URL queries.
-func get_ref_hash_from_type_and_name(repo *git.Repository, ref_type, ref_name string) (ref_hash plumbing.Hash, err error) {
+func getRefHash(repo *git.Repository, ref_type, ref_name string) (ref_hash plumbing.Hash, err error) {
var ref *plumbing.Reference
switch ref_type {
case "":
@@ -8,9 +8,9 @@ import (
"github.com/go-git/go-git/v5/plumbing"
)
-// get_ref_hash_from_type_and_name returns the hash of a reference given its
+// getRefHash returns the hash of a reference given its
// type and name as supplied in URL queries.